# typescript-lambda-api-local

Extension module for the `typescript-lambda-api` package which enables running lambda REST API's locally using express.

## Getting Started

- Install this package and types for Node.js:

```shell
npm install typescript-lambda-api-local
npm install @types/node
```

- In your main typescript file, add the following:

```typescript
import path from "path"

import { ApiConsoleApp } from "typescript-lambda-api-local"

// if you already have controllers, point to the their directory instead of 'controllers'
let app = new ApiConsoleApp(path.join(__dirname, "controllers"))

app.run(process.argv)
```

- Add a `controllers` directory beside your main typescript file (if you already have a set of controllers, change the 'controllers' parameter to the correct path in the above code)

- Create a new file in `controllers` named `HelloWorldController.ts`, add the following:

```typescript
import { injectable } from "inversify";
import { apiController, GET } from "typescript-lambda-api"

@injectable()
@apiController("/hello-world")
export class HelloWorldController {
    @GET()
    public get() {
        return {
            "hello": "world"
        }
    }
}
```

- Compile and run the resulting Javascript in Node.js

- Run the following command to see your API in action:

```shell
wget -qO - http://localhost:5555/hello-world/
```
- You should see:

```json
{"hello":"world"}
```
